---
title: '[공지] 추석연휴 휴무공지'
category: 공지사항
tags:
  - 공지사항
datetime: 2024-09-13T09:02:24.352Z
---

안녕하세요, 포트원 고객지원팀입니다.

이번 한 해도 변함없이 포트원을 사랑해주셔서 무한한 감사를 전해드리며,

이번 추석을 맞이하여 고객지원센터 휴무 일정을 안내 드립니다.

#### &#x20;🍂 **추석 연휴 고객센터 운영 안내**

- **내용 : 추석연휴로 인한 휴무 일정 공지**
- **기간 : 2024년 9월 16일(월) \~ 09월 18일(수)**

---

연휴 기간은 고객센터 상담 및 PG가입 접수건 진행이 불가능한 점 양해 부탁드리며,
문의 사항이 있을 경우 이메일 및 톡 상담(카카오톡, 채널톡)으로 남겨주시면 09월 19일(목)부터 순차적으로 빠른 답변드리겠습니다.

모두 건강하고 풍요로운 한가위 보내시고, 오가는 귀향길 안전운전하시기 바랍니다.

감사합니다.

포트원 드림
